@@ -28,28 +28,29 @@
 #' @examples
 #' library(dplyr)
 #'
-#' my_lambda <- penalty() %>%
+#' my_lambda <- penalty() |>
 #'   value_set(-4:-1)
 #'
 #' try(
 #'   range_validate(my_lambda, c(-10, NA)),
 #'   silent = TRUE
-#' ) %>%
+#' ) |>
 #'   print()
 #'
 #' range_get(my_lambda)
 #'
-#' my_lambda %>%
-#'   range_set(c(-10, 2)) %>%
+#' my_lambda |>
+#'   range_set(c(-10, 2)) |>
 #'   range_get()
 #'
 #' @export
-range_validate <- function(object,
-                           range,
-                           ukn_ok = TRUE,
-                           ...,
-                           call = caller_env()
-                           ) {
+range_validate <- function(
+  object,
+  range,
+  ukn_ok = TRUE,
+  ...,
+  call = caller_env()
+) {
   ukn_txt <- if (ukn_ok) {
     c(i = "{.code Inf} and {.code unknown()} are acceptable values.")
   } else {
